# Notes

These are any notes on design decisions, prototypes, background that don't make it into the package.

They can be the material for a blog post or paper later on!

```{toctree}
:maxdepth: 1
:glob:
:reversed:

*
```
